@@ -8,6 +8,22 @@ from .. import etc
 
 class EditableTextConfigurationTestCase(unittest.TestCase):
 
+    def test_load(self):
+        cfg = etc.load('app.conf')
+        self.assertIn('secrets', cfg)
+        self.assertIn('include', cfg)
+        self.assertEqual(cfg.include[0], 'conf.d')
+
+    def test_load_nonexisting(self):
+        cfg = etc.load('does-not-exist.conf')
+        self.assertEqual(cfg, None)
+
+    def test_load_fragments(self):
+        cfg = etc.load('conf.d')
+        self.assertIn('secrets', cfg)
+        self.assertIn('foo', cfg.secrets)
+        self.assertEqual(cfg.secrets.foo, 'bar')
+
     def test_render_with_variable(self):
         value = etc.render('${foo}', foo='bar')
         self.assertEqual(value, 'bar')
